# 1C discharge from full

Discharge lithium-ion battery from full charge at 1C, using the initial conditions from the paper

>Ecker, Madeleine, et al. "Parameterization of a physico-chemical model of a lithium-ion battery II. Model validation." Journal of The Electrochemical Society 162.9 (2015): A1849-A1857..

